/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 */

package org.apache.isis.core.objectstore.internal;

import org.apache.isis.core.metamodel.adapter.oid.Oid;
import org.apache.isis.core.metamodel.spec.ObjectSpecId;
import org.apache.isis.core.metamodel.spec.ObjectSpecification;
import org.apache.isis.core.runtime.system.persistence.IdentifierGeneratorDefault;

/**
 * Represents the persisted objects.
 * 
 * Attached and detached to each session.
 */
public interface ObjectStorePersistedObjects {

    public IdentifierGeneratorDefault.Memento getOidGeneratorMemento();

    public void saveOidGeneratorMemento(IdentifierGeneratorDefault.Memento memento);

    public void registerService(ObjectSpecId objectSpecId, Oid oid);

    public Oid getService(ObjectSpecId objectSpecId);

    public Iterable<ObjectSpecification> specifications();

    public ObjectStoreInstances instancesFor(ObjectSpecification spec);

    public Iterable<ObjectStoreInstances> instances();

    public void clear();

}
